@@ -189,6 +189,16 @@ def test_corner_file_filter(full_with_merge, corner):
     assert file_filters.sort_file_list(sub_list) == file_filters.sort_file_list(corner)
 
 
+def test_result_json_file_filter(full_with_merge, full_without_merge, merge, unmerge):
+    sub_list = file_filters.result_json_filter(full_with_merge)
+    assert file_filters.sort_file_list(sub_list) == file_filters.sort_file_list(merge)
+    assert file_filters.sort_file_list(sub_list) != file_filters.sort_file_list(unmerge)
+
+    sub_list = file_filters.result_json_filter(full_without_merge)
+    assert file_filters.sort_file_list(sub_list) != file_filters.sort_file_list(merge)
+    assert file_filters.sort_file_list(sub_list) == file_filters.sort_file_list(unmerge)
+
+
 def test_custom_path_file_filter(full_without_merge, merge, png_data, png_extra_dir, index):
     # Test here is not exactly comprehensive, but it's good enough for now
     full = full_without_merge + merge
